import platform
import unittest

import pyrfume


class DataLoadRemoteTestCase(unittest.TestCase):
    def test_load_manoel_2021(self):
        pyrfume.load_data("manoel_2021/behavior.csv")

    def test_load_snitz_2013(self):
        pyrfume.load_data("snitz_2013/behavior.csv")
        pyrfume.load_data("snitz_2013/molecules.csv")

    def test_load_ravia_2020(self):
        pyrfume.load_data("ravia_2020/behavior_1.csv")
        pyrfume.load_manifest("ravia_2020")

    @unittest.skipIf("spike" not in platform.node(), "Only tested on Spike")
    def test_load_morgan_skipped(self):
        my_cids = [129, 239]
        morgan_sim = pyrfume.load_data("morgan/features_sim.csv", cids=my_cids)
        self.assertEqual(morgan_sim.shape[0], len(my_cids))


if __name__ == "__main__":
    unittest.main()



import math
import warnings

import pandas as pd

from .base import get_data_path


def find_all_cids(path=None):
    cids = set()
    path = path or get_data_path()
    for archive in path.iterdir():
        if archive.name == "more":
            cids |= set(find_all_cids(archive))
        possible_molecules_file = archive / "molecules.csv"
        if possible_molecules_file.is_file():
            try:
                df = pd.read_csv(possible_molecules_file, index_col=0)
            except Exception:
                warnings.warn("Could not read %s." % possible_molecules_file)
            else:
                cids |= set(df.index)
    cids = sorted([x for x in cids if x > 0 and not math.isnan(x)])
    return cids



import sys
import unittest

from .test_config_data import *
from .test_datajoint_tools import DataJointTestCase
from .test_docs import *
from .test_load_data import *
from .test_make_solutions import *
from .test_mixture import *
from .test_odorants import *
from .test_others_in__init__ import *
from .test_physics import *
from .test_test import *


def main():
    buffer = "buffer" in sys.argv
    database = "database" in sys.argv
    sys.argv = sys.argv[:1]

    if not database:
        globals().pop("DataJointTestCase")

    unittest.main(buffer=buffer)


if __name__ == "__main__":
    main()



import unittest

import datajoint as dj
import pandas as pd


class DataJointTestCase(unittest.TestCase):
    def setUp(self):
        dj.config["database.host"] = "127.0.0.1"
        dj.config["database.user"] = "root"
        dj.config["database.password"] = "simple"

    def test_schematizing_odorants(self):
        """Test case for schematizations of classes in the odorants module
        and inserting sample data into datajoint table.
        """

        from pyrfume import datajoint_tools as djt
        from pyrfume.odorants import ChemicalOrder, Compound, Molecule, Solution, Vendor

        schematized_classes = {}
        schema = dj.schema("test_schema")
        schema.drop(force=True)
        schema = dj.schema("test_schema", schematized_classes)

        classes_tobe_schematized = ["Molecule", "Vendor", "ChemicalOrder", "Compound", "Solution"]
        for cls_name in classes_tobe_schematized:
            schematized_classes[cls_name] = djt.schematize(locals()[cls_name], schema)

        # test if definition defined.
        for cls_name in classes_tobe_schematized:
            self.assertIsInstance(schematized_classes[cls_name].definition, str)

        Molecule = schematized_classes["Molecule"]
        Molecule.insert1(
            {"cid": 6334, "cas": "", "name": "propane", "iupac": "propane", "synonyms": ""}
        )
        molecules = pd.DataFrame(Molecule.fetch())
        self.assertEqual(molecules.shape[0], 1)

        Vendor = schematized_classes["Vendor"]
        Vendor.insert1({"name": "vendor1", "url": "www.vendor1.com"})
        vendors = pd.DataFrame(Vendor.fetch())
        self.assertEqual(vendors.shape[0], 1)

        ChemicalOrder = schematized_classes["ChemicalOrder"]
        ChemicalOrder.insert1({"molecule_id": 1, "vendor_id": 1, "part_id": 1, "purity": 0.5})
        chemicalorders = pd.DataFrame(ChemicalOrder.fetch())
        self.assertEqual(chemicalorders.shape[0], 1)

        Compound = schematized_classes["Compound"]
        Compound.insert1(
            {
                "chemicalorder_id": 1,
                "stock": "enough",
                "is_solvent": 1,
                "date_arrived": "2020-09-27 02:18:24",
                "date_opened": "2020-09-27 02:18:24",
            }
        )
        compounds = pd.DataFrame(Compound.fetch())
        self.assertEqual(compounds.shape[0], 1)

        Solution = schematized_classes["Solution"]
        Solution.insert1({"date_created": "2020-09-27 02:18:24"})
        solutions = pd.DataFrame(Solution.fetch())
        self.assertEqual(solutions.shape[0], 1)

        Solution.Component.insert1({"solution_id": 1, "compound_id": 1, "value": 1.0})
        solution_components = pd.DataFrame(Solution.Component.fetch())
        self.assertEqual(solution_components.shape[0], 1)


if __name__ == "__main__":
    unittest.main()



import platform
import unittest
from pathlib import Path

import nbformat
from nbconvert.preprocessors import ExecutePreprocessor


class DocsTest(unittest.TestCase):
    def setUp(self):
        import pyrfume

        pyrfume_dir = Path(pyrfume.__path__[0]).parent
        self.docs_path = pyrfume_dir / "docs"
        # pyrfume.set_data_path(pyrfume_dir.parent / 'pyrfume-data')

    def execute(self, path):
        with open(path) as f:
            nb = nbformat.read(f, as_version=4)
        ep = ExecutePreprocessor(timeout=600, kernel_name="python3")
        ep.preprocess(nb)

    def execute_doc(self, name):
        self.execute(self.docs_path / (name + ".ipynb"))

    def test_1_your_data(self):
        self.execute_doc("your-data")

    @unittest.skipIf("spike" not in platform.node(), "Only tested on Spike")
    def test_2_featurization(self):
        self.execute_doc("featurization")

    def test_3_visualization(self):
        self.execute_doc("visualization")

    def test_4_published_data(self):
        self.execute_doc("published-data")


if __name__ == "__main__":
    unittest.main()



import unittest

import numpy as np

from pyrfume.features import get_maximum_tanimoto_similarity, tanimoto_sim
from pyrfume.odorants import all_smiles, smiles_to_mol


class TanimotoTestCase(unittest.TestCase):
    def setUp(self):
        self.n = 100
        smiles = all_smiles()[: self.n]  # First 100 smiles
        mols = smiles_to_mol(smiles)
        self.mols = list(mols.values())

    def test_tanimoto_sim(self):
        sim = tanimoto_sim(self.mols[0], self.mols[1])
        self.assertIsInstance(sim, float)
        self.assertGreaterEqual(sim, 0.0)
        self.assertLess(sim, 1.0)

    def test_bulk_tanimoto(self):
        # First 50 vs last 50
        m = int(self.n / 2)
        sims = get_maximum_tanimoto_similarity(self.mols[:m], self.mols[m:])
        self.assertIsInstance(sims, np.ndarray)
        self.assertEqual(len(sims), m)
        self.assertGreaterEqual(sims.min(), 0.0)
        self.assertLess(sims.max(), 1.0)  # None should be maximally self-similar


if __name__ == "__main__":
    unittest.main()



import unittest
from pathlib import Path


class DataAndConfigTestCase(unittest.TestCase):
    def test_init_reset_config(self):
        from pyrfume import init_config, reset_config

        init_config(False)
        reset_config()
        init_config(True)

    def test_read_write_config(self):
        from pyrfume import read_config, write_config

        write_config("PATHS", "a", "b")
        self.assertEqual(read_config("PATHS", "a"), "b")

    def test_data_path(self):
        from pyrfume import get_data_path, set_data_path
        from pyrfume.base import DEFAULT_DATA_PATH, PACKAGE_DIR

        curr_data_path = get_data_path()

        path_not_exists = PACKAGE_DIR / "THIS_IS_AN_INVALID_PATH"
        self.assertRaises(Exception, set_data_path, path_not_exists, create=False)
        self.assertRaises(Exception, get_data_path, path_not_exists, create=False)

        path1 = PACKAGE_DIR / "unit_test"
        set_data_path(path1)
        path2 = get_data_path()
        self.assertEqual(path1, path2)

        Path(DEFAULT_DATA_PATH).mkdir(exist_ok=True)
        set_data_path(DEFAULT_DATA_PATH)
        path3 = get_data_path()
        self.assertEqual(path3, DEFAULT_DATA_PATH)

        set_data_path(curr_data_path)

    def test_load_data(self):
        import os

        import pandas as pd

        from pyrfume import load_data, save_data
        from pyrfume.base import DEFAULT_DATA_PATH

        data = {"col1": [1, 2], "col2": [3, 4]}
        file_path = DEFAULT_DATA_PATH / "data.pkl"
        path_not_exists = DEFAULT_DATA_PATH / "THIS_IS_AN_INVALID_PATH"

        self.assertRaises(Exception, save_data, data, path_not_exists)
        save_data(data, file_path)

        data_gain = load_data(file_path)
        self.assertEqual(data_gain, data)
        os.remove(file_path)

        file_path = DEFAULT_DATA_PATH / "data.csv"

        df = pd.DataFrame(data)
        save_data(df, file_path)

        data_again = load_data(file_path)

        for index1 in range(len(data_again.values)):
            for index2 in range(len(data_again.values[index1])):
                self.assertEqual(data_again.values[index1][index2], df.values[index1][index2])

        os.remove(file_path)

    def test_save_data(self):
        from pyrfume.base import (  # noqa: F401 (not sure what this is for? -- TODO)
            DEFAULT_DATA_PATH,
        )


if __name__ == "__main__":
    unittest.main()
